.. ppsi documentation master file, created by
   sphinx-quickstart on Mon Jan 11 13:32:41 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree** directive.

#################################
Welcome to PPSI documentation!
#################################

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README.rst
   INSTALL.rst
   configure.rst
   usage.rst
   source_code_doc.rst

#################################
Indices and tables
#################################

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
